defaultLogger constant

Logger const defaultLogger

The logger that's used when no others are selected. This is always Logger.stderr, but with the value for color chosen based on whether the current system supports terminal colors.

Implementation

static const Logger defaultLogger = DefaultLogger();